export default {
    "message": "Cannot use keyword 'await' outside an async function",
    "column": 7,
    "index": 6,
    "lineNumber": 1
};
